@@ -158,7 +158,27 @@ def last_n(n=1):
 
 def get_dataset(country, from_, to_, keyword=None):
     global elastic_vars
-    if keyword!=None:
+    if keyword==None or keyword=="":
+                query = {
+            "query": { 
+                "bool": {
+                    "filter":[
+                        {"range":{
+                            "date":{
+                                "gte": from_,
+                                "lt": to_
+                                }
+                            }
+                        },
+                        {"term":{
+                            "country": country
+                            }
+                        }
+                        ]
+                    }
+                }
+            }
+    else:
         query = {
             "query": { 
                 "bool": {
@@ -182,27 +202,8 @@ def get_dataset(country, from_, to_, keyword=None):
                         ]
                     }
                 }
-            }
-    else:
-        query = {
-            "query": { 
-                "bool": {
-                    "filter":[
-                        {"range":{
-                            "date":{
-                                "gte": from_,
-                                "lt": to_
-                                }
-                            }
-                        },
-                        {"term":{
-                            "country": country
-                            }
-                        }
-                        ]
-                    }
-                }
-            }
+            }        
+
     res = elastic_vars["__es__"].search(index="news", body=query, size=10000)
     n_news = res['hits']['total']['value']
     if n_news == 10000:
