@@ -6,19 +6,20 @@ import matplotlib.pyplot as plt
 from spacy import util as util
 import subprocess
 
-nlp=""
-matcher=""
+ngram_vars={
+    "nlp":"",
+    "matcher":""
+}
 def setup():
-    global nlp
-    global matcher
-    nlp = LOAD('es_core_news_md', disable=['parser','ner','textcat','...'] )
-    matcher = Matcher(nlp.vocab)
+    global ngram_vars
+    ngram_vars["nlp"] = LOAD('es_core_news_md', disable=['parser','ner','textcat','...'] )
+    ngram_vars["matcher"] = Matcher(ngram_vars["nlp"].vocab)
 
     pattern_1 = [{"POS": "NOUN"},{"LOWER": "de"}, {"POS": "NOUN"}]
     pattern_2 = [{"POS": "NOUN"}, {"POS": "ADJ"}]
 
-    matcher.add("NOUN-de-NOUN", [pattern_1])
-    matcher.add("NOUN-ADJ", [pattern_2])   
+    ngram_vars["matcher"].add("NOUN-de-NOUN", [pattern_1])
+    ngram_vars["matcher"].add("NOUN-ADJ", [pattern_2])   
     
 if not util.is_package("es_core_news_md"):
     subprocess.run("python -m spacy download es_core_news_md")
